@@ -5,8 +5,6 @@ from decimal import Decimal
 from trytond.pool import Pool, PoolMeta
 from trytond.transaction import Transaction
 
-__all__ = ['Party']
-
 
 class Party(metaclass=PoolMeta):
     __name__ = 'party.party'
@@ -28,7 +26,7 @@ class Party(metaclass=PoolMeta):
 
         sales = Sale.search([
                 ('party', 'in', [p.id for p in parties]),
-                ('state', '=', 'processing'),
+                ('state', 'in', ['confirmed', 'processing']),
                 ])
         for sale in sales:
             amount = 0
